@@ -3,14 +3,19 @@
 import os
 from functools import partial
 from pathlib import Path
-from typing import Any, Dict, List, Optional, Tuple, Union
+from typing import Any, Callable, Dict, List, Optional, Tuple, Union
 
 from anyio import to_thread
 from prefect import get_run_logger, task
 from prefect.blocks.abstract import DatabaseBlock
 from prefect.utilities.asyncutils import run_sync_in_worker_thread, sync_compatible
 from prefect.utilities.hashing import hash_objects
-from pydantic import Field
+from pydantic import VERSION as PYDANTIC_VERSION
+
+if PYDANTIC_VERSION.startswith("2."):
+    from pydantic.v1 import Field
+else:
+    from pydantic import Field
 
 from prefect_gcp.credentials import GcpCredentials
 
@@ -52,8 +57,9 @@ async def bigquery_query(
     to_dataframe: bool = False,
     job_config: Optional[dict] = None,
     project: Optional[str] = None,
+    result_transformer: Optional[Callable[[List["Row"]], Any]] = None,
     location: str = "US",
-) -> List["Row"]:
+) -> Any:
     """
     Runs a BigQuery query.
 
@@ -78,6 +84,7 @@ async def bigquery_query(
             (e.g., dataset references will be rejected).
         project: The project to initialize the BigQuery Client with; if not
             provided, will default to the one inferred from your credentials.
+        result_transformer: Function that can be passed to transform the result of a query before returning. The function will be passed the list of rows returned by BigQuery for the given query.
         location: Location of the dataset that will be queried.
 
     Returns:
@@ -156,10 +163,14 @@ async def bigquery_query(
         job_config=job_config,
     )
     result = await to_thread.run_sync(partial_query)
+
     if to_dataframe:
         return result.to_dataframe()
     else:
-        return list(result)
+        if result_transformer:
+            return result_transformer(result)
+        else:
+            return list(result)
 
 
 @task
@@ -546,7 +557,7 @@ class BigQueryWarehouse(DatabaseBlock):
     """  # noqa
 
     _block_type_name = "BigQuery Warehouse"
-    _logo_url = "https://images.ctfassets.net/gm98wzqotmnx/4CD4wwbiIKPkZDt4U3TEuW/c112fe85653da054b6d5334ef662bec4/gcp.png?h=250"  # noqa
+    _logo_url = "https://cdn.sanity.io/images/3ugk85nk/production/10424e311932e31c477ac2b9ef3d53cefbaad708-250x250.png"  # noqa
     _documentation_url = "https://prefecthq.github.io/prefect-gcp/bigquery/#prefect_gcp.bigquery.BigQueryWarehouse"  # noqa: E501
 
     gcp_credentials: GcpCredentials
