@@ -13,7 +13,12 @@ from prefect.filesystems import WritableDeploymentStorage, WritableFileSystem
 from prefect.logging import disable_run_logger
 from prefect.utilities.asyncutils import run_sync_in_worker_thread, sync_compatible
 from prefect.utilities.filesystem import filter_files
-from pydantic import Field, validator
+from pydantic import VERSION as PYDANTIC_VERSION
+
+if PYDANTIC_VERSION.startswith("2."):
+    from pydantic.v1 import Field, validator
+else:
+    from pydantic import Field, validator
 
 # cannot be type_checking only or else `fields = cls.schema()` raises
 # TypeError: issubclass() arg 1 must be a class
@@ -502,9 +507,9 @@ class DataFrameSerializationFormat(Enum):
         "parquet",
         "snappy",
         "application/octet-stream",
-        ".parquet.snappy",
+        ".snappy.parquet",
     )
-    PARQUET_GZIP = ("parquet", "gzip", "application/octet-stream", ".parquet.gz")
+    PARQUET_GZIP = ("parquet", "gzip", "application/octet-stream", ".gz.parquet")
 
     @property
     def format(self) -> str:
@@ -564,7 +569,7 @@ class GcsBucket(WritableDeploymentStorage, WritableFileSystem, ObjectStorageBloc
         ```
     """
 
-    _logo_url = "https://images.ctfassets.net/gm98wzqotmnx/4CD4wwbiIKPkZDt4U3TEuW/c112fe85653da054b6d5334ef662bec4/gcp.png?h=250"  # noqa
+    _logo_url = "https://cdn.sanity.io/images/3ugk85nk/production/10424e311932e31c477ac2b9ef3d53cefbaad708-250x250.png"  # noqa
     _block_type_name = "GCS Bucket"
     _documentation_url = "https://prefecthq.github.io/prefect-gcp/cloud_storage/#prefect_gcp.cloud_storage.GcsBucket"  # noqa: E501
 
@@ -870,7 +875,12 @@ class GcsBucket(WritableDeploymentStorage, WritableFileSystem, ObjectStorageBloc
         client = self.gcp_credentials.get_cloud_storage_client()
 
         bucket_path = self._join_bucket_folder(folder)
-        self.logger.info(f"Listing blobs in bucket {bucket_path}.")
+        if bucket_path is None:
+            self.logger.info(f"Listing blobs in bucket {self.bucket!r}.")
+        else:
+            self.logger.info(
+                f"Listing blobs in folder {bucket_path!r} in bucket {self.bucket!r}."
+            )
         blobs = await run_sync_in_worker_thread(
             client.list_blobs, self.bucket, prefix=bucket_path
         )
@@ -903,20 +913,25 @@ class GcsBucket(WritableDeploymentStorage, WritableFileSystem, ObjectStorageBloc
             from prefect_gcp.cloud_storage import GcsBucket
 
             gcs_bucket = GcsBucket.load("my-bucket")
-            gcs_bucket.list_folders('years)
+            gcs_bucket.list_folders("years")
             ```
         """
 
-        bucket_path = self._join_bucket_folder()
-        self.logger.info(f"Listing folders in bucket {bucket_path}.")
+        # Beware of calling _join_bucket_folder twice, see note in method.
+        # However, we just want to use it to check if we are listing the root folder
+        bucket_path = self._join_bucket_folder(folder)
+        if bucket_path is None:
+            self.logger.info(f"Listing folders in bucket {self.bucket!r}.")
+        else:
+            self.logger.info(
+                f"Listing folders in {bucket_path!r} in bucket {self.bucket!r}."
+            )
 
         blobs = await self.list_blobs(folder)
         # gets all folders with full path
-        folders = {
-            str(PurePosixPath(blob.name).parent).replace(".", "") for blob in blobs
-        }
+        folders = {str(PurePosixPath(blob.name).parent) for blob in blobs}
 
-        return list(folders)
+        return [folder for folder in folders if folder != "."]
 
     @sync_compatible
     async def download_object_to_path(
@@ -1273,8 +1288,8 @@ class GcsBucket(WritableDeploymentStorage, WritableFileSystem, ObjectStorageBloc
             to_path: The destination path for the uploaded DataFrame.
             serialization_format: The format to serialize the DataFrame into.
                 When passed as a `str`, the valid options are:
-                'csv', 'csv_gzip',  'parquet', 'parquet_snappy', 'parquet_gz'.
-                Defaults to `OutputFormat.CSV_GZIP`.
+                'csv', 'csv_gzip',  'parquet', 'parquet_snappy', 'parquet_gzip'.
+                Defaults to `DataFrameSerializationFormat.CSV_GZIP`.
             **upload_kwargs: Additional keyword arguments to pass to the underlying
             `Blob.upload_from_dataframe` method.
 
