@@ -1,7 +1,13 @@
 from unittest.mock import Mock
 
 import anyio
-import pydantic
+from pydantic import VERSION as PYDANTIC_VERSION
+
+if PYDANTIC_VERSION.startswith("2."):
+    import pydantic.v1 as pydantic
+else:
+    import pydantic
+
 import pytest
 from googleapiclient.errors import HttpError
 from prefect.exceptions import InfrastructureNotFound
@@ -511,7 +517,9 @@ class TestCloudRunJobContainerSettings:
         cloud_run_job.vpc_connector_name = "vpc_name"
         result = cloud_run_job._jobs_body()
         assert (
-            result["metadata"]["annotations"]["run.googleapis.com/vpc-access-connector"]
+            result["spec"]["template"]["metadata"]["annotations"][
+                "run.googleapis.com/vpc-access-connector"
+            ]
             == "vpc_name"
         )
 
@@ -765,7 +773,6 @@ class TestCloudRunJobRun:
         with pytest.raises(Exception):
             cloud_run_job.run()
         calls = list_mock_calls(mock_client, 2)
-        # breakpoint()
         for call, expected_call in zip(calls, expected_calls):
             assert call.startswith(expected_call)
 
