@@ -168,7 +168,7 @@ class TestGcsBucket:
 
         # blob.txt, base_folder/nested_blob.txt, base_folder/sub_folder/nested_blob.txt
         if not prefix:
-            assert len(actual) == 3
+            assert len(actual) == 4
         # base_folder/sub_folder/nested_blob.txt
         elif prefix == "base_folder/sub_folder":
             assert len(actual) == 1
@@ -234,15 +234,29 @@ class TestGcsBucket:
             }
         )
 
+    def test_list_folders_root_folder(self, gcs_bucket_no_bucket_folder):
+        folders = gcs_bucket_no_bucket_folder.list_folders()
+        assert len(folders) == 3
+        assert set(folders) == {
+            "base_folder",
+            "base_folder/sub_folder",
+            "dotted.folder",
+        }
+
     def test_list_folders_with_root_only(self, gcs_bucket_with_bucket_folder):
-        blobs = gcs_bucket_with_bucket_folder.list_folders()
-        assert len(blobs) == 2
-        assert set(blobs) == {"base_folder", "base_folder/sub_folder"}
+        folders = gcs_bucket_with_bucket_folder.list_folders()
+        assert len(folders) == 2
+        assert set(folders) == {"base_folder", "base_folder/sub_folder"}
 
     def test_list_folders_with_sub_folders(self, gcs_bucket_with_bucket_folder):
-        blobs = gcs_bucket_with_bucket_folder.list_folders("sub_folder/")
-        assert len(blobs) == 1
-        assert blobs[0] == "base_folder/sub_folder"
+        folders = gcs_bucket_with_bucket_folder.list_folders("sub_folder/")
+        assert len(folders) == 1
+        assert folders[0] == "base_folder/sub_folder"
+
+    def test_list_folders_with_dotted_folders(self, gcs_bucket_no_bucket_folder):
+        folders = gcs_bucket_no_bucket_folder.list_folders("dotted.folder/")
+        assert len(folders) == 1
+        assert folders[0] == "dotted.folder"
 
     def test_list_blobs(self, gcs_bucket_no_bucket_folder):
         blobs = gcs_bucket_no_bucket_folder.list_blobs(folder="base_folder/")
@@ -264,10 +278,11 @@ class TestGcsBucket:
 
     def test_list_blobs_root_folder(self, gcs_bucket_no_bucket_folder):
         blobs = gcs_bucket_no_bucket_folder.list_blobs(folder="")
-        assert len(blobs) == 3
+        assert len(blobs) == 4
         assert blobs[0].name == "blob.txt"
         assert blobs[1].name == "base_folder/nested_blob.txt"
         assert blobs[2].name == "base_folder/sub_folder/nested_blob.txt"
+        assert blobs[3].name == "dotted.folder/nested_blob.txt"
 
     def test_download_object_to_path_default(
         self, gcs_bucket_with_bucket_folder, tmp_path
@@ -495,7 +510,7 @@ class TestGcsBucket:
             to_path=to_path,
             serialization_format="parquet_snappy",
         )
-        assert output_to_path == "base_folder/to_path.parquet.snappy"
+        assert output_to_path == "base_folder/to_path.snappy.parquet"
 
     def test_upload_from_dataframe_with_parquet_gzip_output(
         self, gcs_bucket_with_bucket_folder, pandas_dataframe
@@ -506,7 +521,7 @@ class TestGcsBucket:
             to_path=to_path,
             serialization_format="parquet_gzip",
         )
-        assert output_to_path == "base_folder/to_path.parquet.gz"
+        assert output_to_path == "base_folder/to_path.gz.parquet"
 
     def test_upload_from_dataframe_with_csv_output(
         self, gcs_bucket_with_bucket_folder, pandas_dataframe
